# fix-ieeeris.awk
#
# Fix up broken citation entries which were exported by the IEEExplore data
# base (http://ieeexplore.ieee.org/).
#
# Notes:
# * You need to run this also for importing IEEE citation records into endnote.
#
# Programmed with gawk 3.1.1
#
# Copyright (C) by Volker Kuhlmann <VolkerKuhlmann@gmx.de>
# Released under the terms of the GNU General Public License (GPL) Version 2.
# See http://www.gnu.org/ for details.
#
# Volker Kuhlmann
#  16, 18, 27 Feb 2003
#

# Change stuffed volume numbers in records:
# From:
#   VO  -
#   SP  - 1878
#   EP  - 1882 vol.3
# To:
#   VO  - 3
#   SP  - 1878
#   EP  - 1882

BEGIN {
    # remove whitespace and CR from beginning and end of line
    RS="[ \t]*\r*[ \t]*\n\r*[ \t]*"
    ORS="\n"
}

$0 ~ /^VO / {
    volume=$0
    fix=1
    next
}
$0 ~ /^EP / {
    fields = split ($0, endpage, " *[Vv]ol\\.")
    print endpage[1]
    if (fields > 1) {
    	if (match(volume, "^[Vv][Oo] *- *$")) {
	    print volume " " endpage[2]
	} else {
	    print volume " -?which one?- " endpage[2]
	}
    } else {
	print volume
    }
    fix=0
    next
}

# safety stop, if there's no EP field:
fix && $0 ~ /^AB / { print volume; fix=0 }
fix && $0 ~ /^KW / { print volume; fix=0 }
fix && $0 ~ /^ER / { print volume; fix=0 }

{ print }
